carica-dynamodb-tools - Tools to manage DynamoDB tables
==================================================================================

Simple backup and restore utilities for DynamoDB tables.

Development
-----------

The ``vinstall`` script uses the `venv` module to prepare a Python environment useful
for development, so you don't have to build and install carica-dynamodb-tools to be
able to run and test it.

#. Run ``./vinstall``
#. Activate the virtual environment by running ``. ./venv/bin/activate``
#. The ``console_scripts`` listed in ``setup.py`` are now in your path, so you
   can simply run them like:

   ``carica-dynamodb ...``

